"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.hoist = hoist;

var _TBlock = require("../tree/TBlock");

var _TPhrasing = require("../tree/TPhrasing");

var _TText = require("../tree/TText");

/**
 * Wrap text nodes around TPhrasing nodes.
 * @param tnode The parent node of all elements to group.
 */
function groupText(tnode) {
  let newChildren = [];
  const wrapperInit = {
    elementModel: null,
    stylesMerger: tnode.stylesMerger,
    parent: null
  };
  let wrapper = new _TPhrasing.TPhrasing(wrapperInit);
  let wrapperChildren = [];

  for (const child of tnode.children) {
    if (child instanceof _TText.TText || child instanceof _TPhrasing.TPhrasing) {
      wrapperChildren.push(child);
    } else {
      if (wrapperChildren.length) {
        newChildren.push(wrapper);
        wrapper.bindChildren(wrapperChildren);
        wrapper = new _TPhrasing.TPhrasing(wrapperInit);
        wrapperChildren = [];
      }

      newChildren.push(child);
    }
  }

  if (wrapperChildren.length) {
    wrapper.bindChildren(wrapperChildren);
    newChildren.push(wrapper);
  }

  tnode.bindChildren(newChildren);
  return tnode;
}

function hoistNode(tnode) {
  if (tnode instanceof _TText.TText) {
    return tnode;
  }

  tnode.bindChildren(tnode.children.map(hoistNode));

  if (tnode instanceof _TPhrasing.TPhrasing) {
    for (const cnode of tnode.children) {
      if (cnode instanceof _TBlock.TBlock) {
        const newNode = new _TBlock.TBlock(tnode.cloneInitParams());
        newNode.bindChildren(tnode.children);
        const output = groupText(newNode);
        return output;
      }
    }
  } else if (tnode instanceof _TBlock.TBlock) {
    if (tnode.children.length > 0) {
      const output = groupText(tnode);
      return output;
    }
  }

  return tnode;
}

function hoist(tree) {
  return hoistNode(tree);
}
//# sourceMappingURL=hoist.js.map