"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.TDocument = void 0;

var _HTMLElementModel = _interopRequireDefault(require("../model/HTMLElementModel"));

var _domUtils = require("../dom/dom-utils");

var _TBlock = _interopRequireDefault(require("./TBlock"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultContextBase = Object.freeze({
  baseHref: 'about:blank',
  baseTarget: '_self',
  charset: 'utf-8',
  title: '',
  lang: 'en',
  dir: 'ltr',
  links: [],
  meta: []
});

function getDefaultDocumentContext() {
  return Object.assign({}, defaultContextBase, {
    links: [],
    meta: []
  });
}

function extractContextFromHead(head, lang, dir) {
  const context = getDefaultDocumentContext();

  if (lang) {
    context.lang = lang;
  }

  if (dir) {
    context.dir = 'rtl';
  }

  const domNode = head.domNode;
  const children = domNode.children;
  children.filter(_domUtils.isDOMElement).forEach(child => {
    if (child.tagName === 'meta') {
      if (child.attribs.name) {
        context.meta.push(child.attribs);
      } else if (child.attribs.charset) {
        context.charset = child.attribs.charset.toLowerCase();
      }
    } else if (child.tagName === 'link') {
      context.links.push(child.attribs);
    } else if (child.tagName === 'title') {
      for (const titleChild of child.children.filter(_domUtils.isDOMText)) {
        context.title = titleChild.data.trim();
        break;
      }
    } else if (child.tagName === 'base') {
      context.baseHref = child.attribs.href || context.baseHref;
      context.baseTarget = child.attribs.target || context.baseTarget;
    }
  });
  return context;
}

const htmlModel = _HTMLElementModel.default.fromNativeModel({
  tagName: 'html',
  category: 'grouping'
});

const TDocument = function TDocument(init) {
  this.initialize(init);
};

exports.TDocument = TDocument;
TDocument.prototype = Object.create(_TBlock.default.prototype);
Object.defineProperty(TDocument.prototype, 'tagName', {
  value: 'html',
  writable: false
});
Object.defineProperty(TDocument.prototype, 'type', {
  value: 'document',
  writable: false
});
Object.defineProperty(TDocument.prototype, 'displayName', {
  value: 'TDocument',
  writable: false
});
Object.defineProperty(TDocument.prototype, 'elementModel', {
  value: htmlModel,
  writable: false
});

TDocument.prototype.parseChildren = function parseChildren() {
  let head;

  for (const child of this.children) {
    if (child.tagName === 'head') {
      head = child;
      break;
    }
  }

  this.context = Object.freeze(head ? extractContextFromHead(head, this.attributes.lang, this.attributes.dir) : { ...getDefaultDocumentContext(),
    lang: this.attributes.lang,
    dir: this.attributes.dir
  });
};

var _default = TDocument;
exports.default = _default;
//# sourceMappingURL=TDocument.js.map