"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TText = exports.default = void 0;

var _HTMLContentModel = _interopRequireDefault(require("../model/HTMLContentModel"));

var _compose = _interopRequireDefault(require("ramda/src/compose"));

var _textTransforms = require("../flow/text-transforms");

var _TNode = _interopRequireDefault(require("./TNode"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const collapseWhiteSpaces = (0, _compose.default)(_textTransforms.normalizeWhitespaces, _textTransforms.replaceSegmentBreaks, _textTransforms.normalizeZeroWidthWhitespaces, _textTransforms.removeConsecutiveSegmentBreaks, _textTransforms.removeCollapsibleAroundSegmentBreak);
const collapseWhiteSpacesWithEastAsianCharset = (0, _compose.default)(_textTransforms.normalizeWhitespaces, _textTransforms.replaceSegmentBreaks, _textTransforms.removeLineBreaksAroundEastAsianDiscardSet, _textTransforms.normalizeZeroWidthWhitespaces, _textTransforms.removeConsecutiveSegmentBreaks, _textTransforms.removeCollapsibleAroundSegmentBreak);

const TText = function TText(init) {
  this.initialize(init);
}; //@ts-ignore


exports.TText = TText;
TText.prototype = new _TNode.default('text', 'TText', {
  data: {
    get() {
      return this.init.textNode.data;
    },

    set(data) {
      this.init.textNode.data = data;
    }

  }
});

TText.prototype.matchContentModel = function matchContentModel(contentModel) {
  return contentModel === _HTMLContentModel.default.textual || contentModel === _HTMLContentModel.default.mixed;
};

TText.prototype.isCollapsibleLeft = function isCollapsibleLeft() {
  return this.hasWhiteSpaceCollapsingEnabled && !this.isEmpty() && this.data[0] === ' ';
};

TText.prototype.isCollapsibleRight = function isCollapsibleRight() {
  return this.hasWhiteSpaceCollapsingEnabled && !this.isEmpty() && this.data[this.data.length - 1] === ' ';
};

TText.prototype.isEmpty = function isEmpty() {
  // Only anonymous text nodes can be considered "empty"
  return this.tagName === null && !this.data.length;
};

TText.prototype.trimLeft = function trimLeft() {
  if (this.isCollapsibleLeft()) {
    this.data = this.data.slice(1);
  }
};

TText.prototype.trimRight = function trimRight() {
  if (this.isCollapsibleRight()) {
    this.data = this.data.substr(0, this.data.length - 1);
  }
};

TText.prototype.collapseChildren = function collapseChildren(params) {
  if (this.hasWhiteSpaceCollapsingEnabled) {
    if (params.removeLineBreaksAroundEastAsianDiscardSet) {
      this.data = collapseWhiteSpacesWithEastAsianCharset(this.data);
    } else {
      this.data = collapseWhiteSpaces(this.data);
    }
  }

  return null;
};

var _default = TText;
exports.default = _default;
//# sourceMappingURL=TText.js.map